Crate pklr

Crate pklr 

Re-exports

pub use error::Error;
pub use error::Result;
pub use eval::Evaluator;
pub use value::Value;
pub use reqwest;

Modules

error
eval
lexer
parser
value

Structs

EvalOptions
Options for configuring the pkl evaluator.

Functions

analyze_imports
Analyze imports of a pkl file, returning all transitive local file dependencies.
eval_to_json
Evaluate a pkl file and return its contents as a JSON value. This is the primary entry point for use in tools like hk.
eval_to_json_with_client
Evaluate a pkl file with a custom HTTP client for proxy/CA configuration.
eval_to_json_with_options
Evaluate a pkl file with full configuration options.