Re-exports
pub use error::Error;pub use error::Result;pub use eval::Evaluator;pub use value::Value;pub use reqwest;
Modules
Structs
- Eval
Options - Options for configuring the pkl evaluator.
Functions
- analyze_
imports - Analyze imports of a pkl file, returning all transitive local file dependencies.
- eval_
to_ json - Evaluate a pkl file and return its contents as a JSON value. This is the primary entry point for use in tools like hk.
- eval_
to_ json_ with_ client - Evaluate a pkl file with a custom HTTP client for proxy/CA configuration.
- eval_
to_ json_ with_ options - Evaluate a pkl file with full configuration options.